import numpy as np
import math
import logging


def fast_hist(predicted, target, num_classes):
    logging.debug("Inside fast_hist routine")
    k = (predicted >= 0) & (target < num_classes)
    return np.bincount(num_classes * predicted[k].astype(np.uint8) + target[k],
                       minlength=num_classes**2).reshape(num_classes, num_classes)


def cal_kappa(hist):
    logging.debug("Enter cal_kappa routine")
    if hist.sum() == 0:
        po = 0
        pe = 1
        kappa = 0
    else:
        po = np.diag(hist).sum() / hist.sum()
        pe = np.matmul(hist.sum(1), hist.sum(0).T) / hist.sum() ** 2
        if pe == 1:
            kappa = 0
        else:
            kappa = (po - pe) / (1 - pe)
    logging.debug("Exit cal_kappa routine")
    return kappa


def mIoU_and_SeK(predicted, target, num_classes):
    logging.debug("Enter mIoU_and_SeK routine")
    hist = fast_hist(predicted.flatten(), target.flatten(), num_classes)
    hist_fg = hist[1:, 1:]
    c2hist = np.zeros((2, 2))
    c2hist[0][0] = hist[0][0]
    c2hist[0][1] = hist.sum(1)[0] - hist[0][0]
    c2hist[1][0] = hist.sum(0)[0] - hist[0][0]
    c2hist[1][1] = hist_fg.sum()
    hist_n0 = hist.copy()
    hist_n0[0][0] = 0
    kappa_n0 = cal_kappa(hist_n0)
    iu = np.diag(c2hist) / (c2hist.sum(1) + c2hist.sum(0) - np.diag(c2hist))
    IoU_fg = iu[1]
    IoU_mean = (iu[0] + iu[1]) / 2
    Sek = (kappa_n0 * math.exp(IoU_fg)) / math.e

    logging.debug("Exit mIoU_and_SeK routine")
    return IoU_mean, Sek


def mIoU(predicted, target, num_classes):
    logging.debug("Evaluating mIoU")
    return mIoU_and_SeK(predicted, target, num_classes)[0]


def SeK(predicted, target, num_classes):
    logging.debug("Evaluating SeK")
    return mIoU_and_SeK(predicted, target, num_classes)[1]
